## Tools

Tools are scripts you should use to accomplish your tasks.

Use the provided tools as much as possible in your work. 
Only develop bespoke scripts when the existing tools
are not an appropriate fit for the task. 

If a python `venv` is available as part of the skill or role 
that owns a tool, always use that `venv` to invoke the tool.
